unit CaptionPanel;

{$IFDEF FPC}
  {$mode objfpc}{$H+}
{$ENDIF};

interface

uses
  SysUtils, Classes, Controls, StdCtrls, ExtCtrls, Buttons, Graphics, ComCtrls,
  ToolWin
  {$IFDEF FPC}
  ,LResources
  {$ENDIF};

type

  TCaptionBarButtonSet = (cbb_help, cbb_iconize, cbb_minimize, cbb_maximize,
                          cbb_close);
  TCaptionBarButtons = Set of TCaptionBarButtonSet;
  TCaptionBarButton = cbb_help..cbb_close;

  TCaptionPanel = class(TCustomPanel)
  private
    { Private-Deklarationen }
    FButtons: TCaptionBarButtons;
    FButtonPanel: TCustomPanel;
    FFormIcon: TImage;
    FOwnerCaption: TPanel;

    function  GetOwnerCaption: string;
    procedure SetOwnerCaption(Value: string);
    function  GetFormIcon: TPicture;
    procedure SetFormIcon(Value: TPicture);
    function  GetCaptionFont: TFont;
    procedure SetCaptionFont(Value: TFont);
    function  GetCaptionColor: TColor;
    procedure SetCaptionColor(Value: TColor);

    {$IFDEF FPC}
    function  LoadGlyph(const GlyphName: string): TBitmap;
    {$ENDIF}
  protected
    { Protected-Deklarationen }

  public
    { Public-Deklarationen }
    constructor Create(AOwner: TComponent); override;
  published
    { Published-Deklarationen }
    property OwnerCaption: string read GetOwnerCaption write SetOwnerCaption;
    property FormIcon: TPicture read GetFormIcon write SetFormIcon;
    property CaptionFont: TFont read GetCaptionFont write SetCaptionFont;
    property CaptionColor: TColor read GetCaptionColor write SetCaptionColor;
    property Buttons: TCaptionBarButtons read FButtons write FButtons;

  end; // of TCaptionPanel
  
procedure Register();

implementation

procedure Register();
begin
  RegisterComponents('Control-Bars', [TCaptionPanel]);
end; // of Register

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   Create
  Author:    root
  Date:      02-Jan-2007
  Arguments: AOwner: TComponent
-----------------------------------------------------------------------------}
constructor TCaptionPanel.Create(AOwner: TComponent);
const
  cProcName = 'CaptionPanel.TCaptionPanel.Create';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'AOwner: TComponent'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  inherited Create(AOwner);
  Self.BevelInner:= bvLowered;
  Self.BevelOuter:= bvRaised;
  Self.Height:= 26;
  Self.Caption:= '';
  Self.Align:= alTop;
  Self.Parent:= TWinControl(AOwner);
  FFormIcon:= TImage.Create(Self);
  FFormIcon.Height:= Self.ClientHeight;
  FFormIcon.Width := FFormIcon.Height;
  FFormIcon.Align:= alLeft;
  FFormIcon.Parent:= Self;
  FButtonPanel:= TCustomPanel.Create(Self);
  FButtonPanel.Width:= Self.ClientHeight;
  FButtonPanel.Align:= alRight;
  FButtonPanel.Parent:= Self;
  FButtons:= [cbb_close, cbb_maximize, cbb_minimize, cbb_help];
  FOwnerCaption:= TPanel.Create(Self);
  FOwnerCaption.BevelInner:= bvNone;
  FOwnerCaption.BevelOuter:= bvNone;
  FOwnerCaption.BorderWidth:= 2;
  FOwnerCaption.Align:= alClient;
  FOwnerCaption.Alignment:= taLeftJustify;
  FOwnerCaption.Color:= clNavy;
  FOwnerCaption.Font.Style:= [fsBold];
  FOwnerCaption.Font.Color:= clWhite;
  FOwnerCaption.Height:= Self.ClientHeight;
  FOwnerCaption.Caption:= TComponent(AOwner).Name;
  FOwnerCaption.Parent:= Self;
end; // of TCaptionPanel.Create

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetOwnerCaption
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    string
-----------------------------------------------------------------------------}
function TCaptionPanel.GetOwnerCaption: string;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetOwnerCaption';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'string';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Caption;
end; // of TCaptionPanel.GetOwnerCaption

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetOwnerCaption
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: string
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetOwnerCaption(Value: string);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetOwnerCaption';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: string'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Caption) then begin
    FOwnerCaption.Caption:= Value;
  end;
end; // of TCaptionPanel.SetOwnerCaption


{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetFormIcon
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TPicture
-----------------------------------------------------------------------------}
function TCaptionPanel.GetFormIcon: TPicture;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetFormIcon';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TPicture';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FFormIcon.Picture;
end; // of TCaptionPanel.GetFormIcon

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetFormIcon
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TPicture
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetFormIcon(Value: TPicture);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetFormIcon';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TPicture'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> nil) and (Value <> FFormIcon.Picture) then begin
    FFormIcon.Picture:= Value;
  end;
end; // of TCaptionPanel.SetFormIcon

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetCaptionFont
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TFont
-----------------------------------------------------------------------------}
function TCaptionPanel.GetCaptionFont: TFont;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetCaptionFont';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TFont';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Font;
end; // of TCaptionPanel.GetCaptionFont

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetCaptionFont
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TFont
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetCaptionFont(Value: TFont);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetCaptionFont';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TFont'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Font) then begin
    FOwnerCaption.Font:= Value;
  end;
end; // of TCaptionPanel.SetCaptionFont

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetCaptionColor
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TColor
-----------------------------------------------------------------------------}
function TCaptionPanel.GetCaptionColor: TColor;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetCaptionColor';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TColor';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Color;
end; // of TCaptionPanel.GetCaptionColor

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetCaptionColor
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TColor
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetCaptionColor(Value: TColor);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetCaptionColor';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TColor'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Color) then begin
    FOwnerCaption.Color:= Value;
  end;
end; // of TCaptionPanel.SetCaptionColor

{$IFDEF FPC}
{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    LoadGlyph
  Author:    root
  Date:      02-Jan-2007
  Arguments: const GlyphName: string
  Result:    TBitmap
-----------------------------------------------------------------------------}
function TCaptionPanel.LoadGlyph(const GlyphName: string): TBitmap;
const
  cProcName = 'CaptionPanel.TCaptionPanel.LoadGlyph';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'const GlyphName: string'
    // 'TBitmap';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= TPixmap.Create;
  Result.LoadFromLazarusResource(GlyphName);
end; // of TCaptionPanel.LoadGlyph
{$ENDIF}

{-----------------------------------------------------------------------------
 Unit Name: CaptionPanel
 Author:    root
 Date:      02-Jan-2007
 Purpose:
 History:
-----------------------------------------------------------------------------}
initialization
{$IFDEF FPC}
//  {$I resource\captionpanel-regs.lrs}
  {$I captionpanel.lrs}
{$ENDIF}

end.
